# sockets-communication

This module provides a wrapper for the built-in socket module in python. The program provides server and.
client classes, with the communication methods.

first of all
------------

### credits:
- writen and owned by:
  Shahaf Frank-Shapir

- all the rights are saved for:
  Shahaf Frank-Shapir

- programming language:
  python 3.8.6 (100%)

before we start
---------------

### description:
- This module provides a wrapper for the built-in socket module in python. The program provides server and.
  client classes, with the communication methods.

### dependencies:
- opening:
  As for this is a really complex program, which uses a lot of modules, there are required dependencies needed
  in order to run the program. keep in mined the program was writen in python 3.8.6, so any python version lower
  than 3.9.2 might not work properly. Moreover, built-in python modules are being used, so keep that in mind.

run the app
-----------

#### run from windows command line (inside the project directory)
- run with python (3.6.0 or higher) by writing to the command line in the project directory:
````
python server.py
python client.py
python test.py
````